@@ -22,7 +22,6 @@
 #include <fb303/LegacyClock.h>
 #include <fb303/detail/RegexUtil.h>
 #include <folly/Conv.h>
-#include <folly/ExceptionString.h>
 #include <folly/Indestructible.h>
 #include <folly/MapUtil.h>
 #include <folly/String.h>
@@ -318,7 +317,7 @@ int64_t ServiceData::incrementCounter(StringPiece key, int64_t amount) {
 
   //  pessimistically, the key is possibly absent; upsert under wlock
   auto countersWLock = counters_.wlock();
-  auto& ref = (countersWLock->map)[key];
+  auto& ref = (countersWLock->map)[std::string(key)];
 
   // avoid fetch_add() to avoid extra fences, since we hold the lock already
   uint64_t epoch = countersWLock->mapEpoch.load();
@@ -341,7 +340,7 @@ int64_t ServiceData::setCounter(StringPiece key, int64_t value) {
 
   //  pessimistically, the key is possibly absent; upsert under wlock
   auto countersWLock = counters_.wlock();
-  auto& ref = (countersWLock->map)[key];
+  auto& ref = (countersWLock->map)[std::string(key)];
 
   // avoid fetch_add() to avoid extra fences, since we hold the lock already
   uint64_t epoch = countersWLock->mapEpoch.load();
